Supporting Functions for COM-Poisson Regression
# S3 method for cmpfit
summary(object, ...)# S3 method for cmpfit
print(x, ...)
# S3 method for cmpfit
logLik(object, ...)
# S3 method for cmpfit
AIC(object, ..., k = 2)
# S3 method for cmpfit
BIC(object, ...)
# S3 method for cmpfit
coef(object, type = c("vector", "list"), ...)
# S3 method for cmpfit
nu(object, ...)
# S3 method for cmpfit
sdev(object, type = c("vector", "list"), ...)
# S3 method for cmpfit
vcov(object, ...)
# S3 method for cmpfit
equitest(object, ...)
# S3 method for cmpfit
leverage(object, ...)
# S3 method for cmpfit
deviance(object, ...)
# S3 method for cmpfit
residuals(object, type = c("raw", "quantile"), ...)
# S3 method for cmpfit
predict(object, newdata = NULL, type = c("response", "link"), ...)
# S3 method for cmpfit
parametric.bootstrap(object, reps = 1000, report.period = reps + 1, ...)
object of type cmp.
other arguments, such as subset and na.action.
object of type cmp.
Penalty per parameter to be used in AIC calculation.
Specifies quantity to be computed. See details.
New covariates to be used for prediction.
Number of bootstrap repetitions.
Report progress every report.period iterations.
The function residuals returns raw residuals when type = "raw" and
quantile residuals when type = "quantile".
The function predict returns expected values of the outcomes, eveluated at
the computed estimates, when type = "response". When type = "link", a
data.frame is instead returned with columns corresponding to estimates of
lambda and nu.
The function coef returns a vector of coefficient estimates in the form
c(beta, gamma) when type = "vector". When type = "list", the estimates
are returned as a list with named elements beta and gamma.
The type argument behaves the same for the sdev function as it does for
coef.