| glm.cmp, ZICMP support | R Documentation |
Supporting Functions for ZICMP Regression
## S3 method for class 'zicmpfit'
summary(object, ...)
## S3 method for class 'zicmpfit'
print(x, ...)
## S3 method for class 'zicmpfit'
logLik(object, ...)
## S3 method for class 'zicmpfit'
AIC(object, ..., k = 2)
## S3 method for class 'zicmpfit'
BIC(object, ...)
## S3 method for class 'zicmpfit'
coef(object, type = c("vector", "list"), ...)
## S3 method for class 'zicmpfit'
nu(object, ...)
## S3 method for class 'zicmpfit'
sdev(object, type = c("vector", "list"), ...)
## S3 method for class 'zicmpfit'
vcov(object, ...)
## S3 method for class 'zicmpfit'
equitest(object, ...)
## S3 method for class 'zicmpfit'
deviance(object, ...)
## S3 method for class 'zicmpfit'
residuals(object, type = c("raw", "quantile"), ...)
## S3 method for class 'zicmpfit'
predict(object, newdata = NULL, type = c("response", "link"), ...)
## S3 method for class 'zicmpfit'
parametric.bootstrap(object, reps = 1000, report.period = reps + 1, ...)
object |
object of type |
... |
other arguments, such as |
x |
object of type |
k |
Penalty per parameter to be used in AIC calculation. |
type |
Specifies quantity to be computed. See details. |
newdata |
New covariates to be used for prediction. |
reps |
Number of bootstrap repetitions. |
report.period |
Report progress every |
The function residuals returns raw residuals when type = "raw" and
quantile residuals when type = "quantile".
The function predict returns expected values of the outcomes,
eveluated at the computed estimates, when type = "response". When
type = "link", a data.frame is instead returned with
columns corresponding to estimates of lambda, nu, and
p.
The function coef returns a vector of coefficient estimates in the form
c(beta, gamma, zeta) when type = "vector". When type = "list", the
estimates are returned as a list with named elements beta and gamma,
and zeta.
The type argument behaves the same for the sdev function as it does for
coef.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.